==> kubernetes-model-core-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/TopologySpreadConstraintFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TopologySpreadConstraintFluent<A extends TopologySpreadConstraintFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabelSelector();
  public LabelSelector buildLabelSelector();
  public A withLabelSelector(LabelSelector labelSelector);
  public Boolean hasLabelSelector();
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> withNewLabelSelector();
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item);
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> editLabelSelector();
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> editOrNewLabelSelector();
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item);
  public A addToMatchLabelKeys(Integer index,String item);
  public A setToMatchLabelKeys(Integer index,String item);
  public A addToMatchLabelKeys(java.lang.String... items);
  public A addAllToMatchLabelKeys(Collection<String> items);
  public A removeFromMatchLabelKeys(java.lang.String... items);
  public A removeAllFromMatchLabelKeys(Collection<String> items);
  public List<String> getMatchLabelKeys();
  public String getMatchLabelKey(Integer index);
  public String getFirstMatchLabelKey();
  public String getLastMatchLabelKey();
  public String getMatchingMatchLabelKey(Predicate<String> predicate);
  public Boolean hasMatchingMatchLabelKey(Predicate<String> predicate);
  public A withMatchLabelKeys(List<String> matchLabelKeys);
  public A withMatchLabelKeys(java.lang.String... matchLabelKeys);
  public Boolean hasMatchLabelKeys();
  public Integer getMaxSkew();
  public A withMaxSkew(Integer maxSkew);
  public Boolean hasMaxSkew();
  public Integer getMinDomains();
  public A withMinDomains(Integer minDomains);
  public Boolean hasMinDomains();
  public String getNodeAffinityPolicy();
  public A withNodeAffinityPolicy(String nodeAffinityPolicy);
  public Boolean hasNodeAffinityPolicy();
  public String getNodeTaintsPolicy();
  public A withNodeTaintsPolicy(String nodeTaintsPolicy);
  public Boolean hasNodeTaintsPolicy();
  public String getTopologyKey();
  public A withTopologyKey(String topologyKey);
  public Boolean hasTopologyKey();
  public String getWhenUnsatisfiable();
  public A withWhenUnsatisfiable(String whenUnsatisfiable);
  public Boolean hasWhenUnsatisfiable();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LabelSelectorNested<N> extends Nested<N>,LabelSelectorFluent<TopologySpreadConstraintFluent.LabelSelectorNested<N>>{
    public N and();
    public N endLabelSelector();
    
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/TopologySpreadConstraintFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TopologySpreadConstraintFluent<A extends TopologySpreadConstraintFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabelSelector();
  public LabelSelector buildLabelSelector();
  public A withLabelSelector(LabelSelector labelSelector);
  public Boolean hasLabelSelector();
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> withNewLabelSelector();
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item);
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> editLabelSelector();
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> editOrNewLabelSelector();
  public TopologySpreadConstraintFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item);
  public A addToMatchLabelKeys(int index,String item);
  public A setToMatchLabelKeys(int index,String item);
  public A addToMatchLabelKeys(java.lang.String... items);
  public A addAllToMatchLabelKeys(Collection<String> items);
  public A removeFromMatchLabelKeys(java.lang.String... items);
  public A removeAllFromMatchLabelKeys(Collection<String> items);
  public List<String> getMatchLabelKeys();
  public String getMatchLabelKey(int index);
  public String getFirstMatchLabelKey();
  public String getLastMatchLabelKey();
  public String getMatchingMatchLabelKey(Predicate<String> predicate);
  public Boolean hasMatchingMatchLabelKey(Predicate<String> predicate);
  public A withMatchLabelKeys(List<String> matchLabelKeys);
  public A withMatchLabelKeys(java.lang.String... matchLabelKeys);
  public Boolean hasMatchLabelKeys();
  public Integer getMaxSkew();
  public A withMaxSkew(Integer maxSkew);
  public Boolean hasMaxSkew();
  public Integer getMinDomains();
  public A withMinDomains(Integer minDomains);
  public Boolean hasMinDomains();
  public String getNodeAffinityPolicy();
  public A withNodeAffinityPolicy(String nodeAffinityPolicy);
  public Boolean hasNodeAffinityPolicy();
  public String getNodeTaintsPolicy();
  public A withNodeTaintsPolicy(String nodeTaintsPolicy);
  public Boolean hasNodeTaintsPolicy();
  public String getTopologyKey();
  public A withTopologyKey(String topologyKey);
  public Boolean hasTopologyKey();
  public String getWhenUnsatisfiable();
  public A withWhenUnsatisfiable(String whenUnsatisfiable);
  public Boolean hasWhenUnsatisfiable();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LabelSelectorNested<N> extends Nested<N>,LabelSelectorFluent<TopologySpreadConstraintFluent.LabelSelectorNested<N>>{
    public N and();
    public N endLabelSelector();
    
  }
  
}
